package App::GetoptLongExamples;

our $DATE = '2019-01-30'; # DATE
our $VERSION = '0.001'; # VERSION

1;
# ABSTRACT: Collection of CLI examples related to Getopt::Long

__END__

=pod

=encoding UTF-8

=head1 NAME

App::GetoptLongExamples - Collection of CLI examples related to Getopt::Long

=head1 VERSION

This document describes version 0.001 of App::GetoptLongExamples (from Perl distribution App-GetoptLongExamples), released on 2019-01-30.

=head1 DESCRIPTION

This distribution provides the following command-line utilities:

=over

=item * L<getopt-long-sample-implicit-dest-classic>

=item * L<getopt-long-sample-implicit-dest-hash-storage>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-GetoptLongExamples>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-GetoptLongExamples>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-GetoptLongExamples>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Getopt::Long>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
